Density (PDF), distribution function (CDF), and hazard function for a discreetly mixed distribution of the Q-Weibull and the exponential distributions.
dmixqwe(x, pdist = .5, a = .8, qdist = 1.5, lambda = .8, b = 1, forceExpectation = F)
pmixqwe(q, pdist = .5, a = .8, qdist = 1.5, lambda = .8, b = 1, forceExpectation = F)
mixqweHazard(x, pdist = .5, a = .8, qdist = 1.5, lambda = .8, b = 1, forceExpectation = F)
vector of quantiles.
parameters, see 'Details'.
logical; if TRUE, the expectation of the distribution is forced to be 1 by letting b be a function of the other parameters.
The PDF for the mixed distribution is:
$$f(x) = p(2-q)\frac{a}{b^a} x^{a-1} \left[1-(1-q)\left(\frac{x}{b}\right)^a\right]^{\frac{1}{1-q}} + (1-p)\frac{1}{\lambda}exp(-\frac{x}{\lambda})$$
if forceExpectation = TRUE the b parameter is a function of the other parameters to force the expectation to be 1.
qWeibullDist for the Q-Weibull distribution and pmixqww for Q-Weibull mixed with the ordinary Weibull.