dmixqww(x, pdist = .5, a = 1.2, qdist = 1.5, theta = .8, gamma = 1, b = 1,
forceExpectation = F)
pmixqww(q, pdist = .5, a = 1.2, qdist = 1.5, theta = .8, gamma = 1, b = 1,
forceExpectation = F)
mixqwwHazard(x, pdist = .5, a = 1.2, qdist = 1.5, theta = .8, gamma = 1, b = 1,
forceExpectation = F)TRUE, the expectation of the distribution is forced to be 1 by letting b be a function of the other parameters.forceExpectation = TRUE the b parameter is a function of the other parameters to force the expectation to be 1.qWeibullDist for the Q-Weibull distribution and pmixqwe for Q-Weibull mixed with the exponential distribution.