dmixinvgauss(x, theta = .2, lambda = .1, gamma = .05, forceExpectation = F)
pmixinvgauss(q, theta = .2, lambda = .1, gamma = .05, forceExpectation = F)
mixinvgaussHazard(x, theta = .2, lambda = .1, gamma = .05, forceExpectation = F)TRUE, the expectation of the distribution is forced to be 1..forceExpectation = TRUE the distribution is transformed by dividing the random variable with its expectation and using the change of variable function.