dmixqwe(x, pdist = .5, a = .8, qdist = 1.5, lambda = .8, b = 1, forceExpectation = F)
pmixqwe(q, pdist = .5, a = .8, qdist = 1.5, lambda = .8, b = 1, forceExpectation = F)
mixqweHazard(x, pdist = .5, a = .8, qdist = 1.5, lambda = .8, b = 1, forceExpectation = F)TRUE, the expectation of the distribution is forced to be 1 by letting b be a function of the other parameters.forceExpectation = TRUE the b parameter is a function of the other parameters to force the expectation to be 1.qWeibullDist for the Q-Weibull distribution and pmixqww for Q-Weibull mixed with the ordinary Weibull.